@@ -1,7 +1,7 @@
 kcvcheck <-
   function(y, nfolds, parallel, foldid) 
 {
-    if (!is.factor(y)) {y <- factor(y)}
+    if (!(is.factor(y))) {y <- factor(y)}
     if (length(unique(y)) == 1L) {
       stop("Input 'y' must contain some variation (i.e., cannot contain only \n
            a single type of label).")
@@ -9,28 +9,18 @@ kcvcheck <-
     if (is.null(nfolds)) {
       nfolds <- 10
     } else {
-      if (!(is.integer(nfolds) || is.numeric(nfolds))) {
-        stop("Input 'nfolds' must be of class 'integer' or 'numeric'.")
-      }
-      if (length(unique(nfolds)) != 1L) {
-        stop("Input 'nfolds' must contain only a single value.")
-      }
+      numcheck(nfolds)
       if ((nfolds %% 1) != 0) {stop("Input 'nfolds' must be an integer.")}
       if ((nfolds < 2) || (nfolds > length(y))) {
         stop("Input 'nfolds' must be an integer between 2 and the \n
-             number of observations, inclusive. Alternatively, the \n
+             number of observations, inclusive. In addition, the \n
              number of observations cannot be less than 'nfolds'.")
       }
     }
     if (is.null(parallel)) {
-      parallel <- F
+      parallel <- FALSE
     } else {
-      if (!(is.logical(parallel))) {
-        stop("Input 'parallel' must be of class 'logical'.")
-      }
-      if (length(unique(parallel)) != 1L) {
-        stop("Input 'parallel' must contain only a single value.")
-      }  
+      logicheck(parallel)
     }
     if (is.null(foldid)) {
       foldid <- sample(rep(1:nfolds, length.out = length(y)))
